diff flys-client/src/main/java/de/intevation/flys/client/client/services/GetArtifactService.java @ 229:924da6695800

Each service is now called with the name of the current locale to set the request object's locale manually in the HttpClient. flys-client/trunk@1681 c6561f87-3c4e-4783-a992-168aeb5c3f6f
author Ingo Weinzierl <ingo.weinzierl@intevation.de>
date Thu, 14 Apr 2011 07:53:01 +0000
parents f03c34bec364
children bc06a671ef60
line wrap: on
line diff
--- a/flys-client/src/main/java/de/intevation/flys/client/client/services/GetArtifactService.java	Tue Apr 12 13:48:11 2011 +0000
+++ b/flys-client/src/main/java/de/intevation/flys/client/client/services/GetArtifactService.java	Thu Apr 14 07:53:01 2011 +0000
@@ -17,13 +17,15 @@
     /**
      * This method inserts new data into the an existing artifact.
      *
      * @param serverUrl The url of the artifact server.
      * @param uuid The artifact's identifier.
      * @param hash The artifact's hash.
      *
      * @return the artifact.
      */
-    Artifact getArtifact(String url, String uuid, String hash)
+    Artifact getArtifact(String url, String locale, String uuid, String hash)
     throws ServerException;
 }
 // vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
@@ -17,13 +17,15 @@
      * This method inserts new data into the an existing artifact.
      *
-     * @param serverUrl The url of the artifact server.
+     * @param url The url of the artifact server.
+     * @param locale The string representation of a locale that is used for the
+     * request.
      * @param uuid The artifact's identifier.
      * @param hash The artifact's hash.

http://dive4elements.wald.intevation.org